@@ -5,6 +5,7 @@ use warnings;
 
 use Data::Dumper ();
 use Locale::TextDomain::OO::Extract::HTML;
+use Path::Iterator::Rule;
 use Path::Tiny qw(path);
 
 our $VERSION = 0;
@@ -16,13 +17,12 @@ my $extractor = Locale::TextDomain::OO::Extract::HTML->new(
     lexicon_ref => \my %lexicon,
 );
 
-my @files
-    = map { path($_) }
-    qw(
-        ./files_to_extract/text.html
-    );
+my @files = Path::Iterator::Rule
+    ->new
+    ->file( qw( *.html *.htm ) )
+    ->all( qw( ./files_to_extract ) );
 
-for my $file (@files) {
+for my $file ( map { path($_) } @files ) {
     $extractor->filename( $file->relative( q{./} )->stringify );
     $extractor->content_ref( \( $file->slurp_utf8 ) );
     $extractor->extract;
@@ -36,7 +36,7 @@ for my $file (@files) {
     ->Useqq(1)
     ->Dump;
 
-# $Id: 14_extract_html.pl 517 2014-10-09 13:52:18Z steffenw $
+# $Id: 14_extract_html.pl 561 2014-11-11 16:12:48Z steffenw $
 
 __END__
 
@@ -51,16 +51,20 @@ $lexicon_ref = {
       }
     },
     "This is a p text." => {
-      msgid => "This is a p text.",
       reference => {
-        "files_to_extract/text.html:8" => undef
+        "files_to_extract/gettext.html:8" => undef,
+        "files_to_extract/gettext_loc.html:8" => undef,
+        "files_to_extract/maketext_loc.html:8" => undef
       }
     },
     "This is an a text." => {
-      msgid => "This is an a text.",
       reference => {
-        "files_to_extract/text.html:10" => undef,
-        "files_to_extract/text.html:13" => undef
+        "files_to_extract/gettext.html:10" => undef,
+        "files_to_extract/gettext.html:13" => undef,
+        "files_to_extract/gettext_loc.html:10" => undef,
+        "files_to_extract/gettext_loc.html:13" => undef,
+        "files_to_extract/maketext_loc.html:10" => undef,
+        "files_to_extract/maketext_loc.html:13" => undef
       }
     }
   }
